@@ -3,11 +3,11 @@ use std::path::PathBuf;
 use chrono::prelude::*;
 use chrono::Duration;
 use chrono_english::*;
-use clap::{ArgEnum, Clap};
+use clap::{ArgEnum, Parser};
 
 use pueue_lib::network::message::Signal;
 
-#[derive(Clap, Debug)]
+#[derive(Parser, Debug)]
 pub enum SubCommand {
     /// Enqueue a task for execution.
     Add {
@@ -235,7 +235,7 @@ pub enum SubCommand {
         /// Send a UNIX signal instead of simply killing the process.
         /// DISCLAIMER: This bypasses Pueue's process handling logic!
         ///     You might enter weird invalid states, use at your own descretion.
-        #[clap(short, long, case_insensitive(true))]
+        #[clap(short, long, ignore_case(true))]
         signal: Option<Signal>,
     },
 
@@ -390,7 +390,7 @@ pub enum SubCommand {
     },
 }
 
-#[derive(Clap, Debug, PartialEq, ArgEnum)]
+#[derive(Parser, ArgEnum, Debug, Clone, PartialEq)]
 pub enum Shell {
     Bash,
     Elvish,
@@ -399,7 +399,7 @@ pub enum Shell {
     Zsh,
 }
 
-#[derive(Clap, Debug)]
+#[derive(Parser, Debug)]
 #[clap(
     name = "Pueue client",
     about = "Interact with the Pueue daemon",
