@@ -1,14 +1,9 @@
 use std::path::PathBuf;
 
-use clap::Clap;
+use clap::Parser;
 
-#[derive(Clap, Debug)]
-#[clap(
-    name = "Pueue daemon",
-    about = "Start the daemon for pueue",
-    author = env!("CARGO_PKG_AUTHORS"),
-    version = env!("CARGO_PKG_VERSION")
-)]
+#[derive(Parser, Debug)]
+#[clap(name = "Pueue daemon", about, author, version)]
 pub struct CliArguments {
     /// Verbose mode (-v, -vv, -vvv)
     #[clap(short, long, parse(from_occurrences))]
